@@ -46,8 +46,9 @@ class FrameMetadataExtractor:
             r"geboren[:\s]*(\d{1,2}\.\d{1,2}\.\d{2,4})",
             r"Geb\.Dat[\.:\s]*(\d{1,2}\.\d{1,2}\.\d{2,4})",
             r"DOB[:\s]*(\d{1,2}\.\d{1,2}\.\d{2,4})",
-            r"(\d{1,2}[\./-]\d{1,2}[\./-]\d{2,4})",  # Date with separators
-            r"(\d{8,10})",  # Compact date format: DDMMYYYY or DD/MM/YYYY condensed
+            r"(\d{10})",  # Compact date format: 10 digits (DDMMYYYYHH or similar) - check first
+            r"(\d{8})",  # Compact date format: DDMMYYYY - check second
+            r"(\d{1,2}[\.\-/]\d{1,2}[\.\-/]\d{2,4})",  # Date with separators - check last
         ]
 
         self.case_patterns = [
@@ -59,10 +60,10 @@ class FrameMetadataExtractor:
         ]
 
         self.date_patterns = [
-            r"Datum[:\s]*(\d{1,2}[\./-\s]+\d{1,2}[\./-\s]+\d{2,4})",
-            r"Date[:\s]*(\d{1,2}[\./-\s]+\d{1,2}[\./-\s]+\d{2,4})",
-            r"Untersuchung[:\s]*(\d{1,2}[\./-\s]+\d{1,2}[\./-\s]+\d{2,4})",
-            r"(\d{1,2}[\./-\s]+\d{1,2}[\./-\s]+\d{2,4})",  # Any date with flexible separators
+            r"Datum[:\s]*(\d{1,2}[\.\-/\s]+\d{1,2}[\.\-/\s]+\d{2,4})",
+            r"Date[:\s]*(\d{1,2}[\.\-/\s]+\d{1,2}[\.\-/\s]+\d{2,4})",
+            r"Untersuchung[:\s]*(\d{1,2}[\.\-/\s]+\d{1,2}[\.\-/\s]+\d{2,4})",
+            r"(\d{1,2}[\.\-/\s]+\d{1,2}[\.\-/\s]+\d{2,4})",  # Any date with flexible separators
         ]
 
         self.time_patterns = [
@@ -184,23 +185,45 @@ class FrameMetadataExtractor:
             return None, None
 
     def _extract_date_of_birth(self, text: str) -> Optional[date]:
-        """Extract date of birth from text."""
+        """
+        Extract date of birth from text with priority ordering:
+        1. Labeled patterns (geb:, geboren:, DOB:) - highest confidence
+        2. Compact formats (8-10 digits) - likely DOB, not exam date
+        3. Dates with separators - lowest priority (could be exam date)
+        """
         try:
-            for pattern in self.dob_patterns:
+            # Priority 1: Try labeled patterns first (geb:, geboren:, etc.)
+            labeled_patterns = self.dob_patterns[:4]
+            for pattern in labeled_patterns:
                 matches = re.findall(pattern, text, re.IGNORECASE)
                 if matches:
                     date_str = matches[0].strip()
+                    parsed_date = self._parse_german_date(date_str)
+                    if parsed_date:
+                        logger.debug(f"Found labeled DOB: {parsed_date} from '{date_str}'")
+                        return parsed_date
 
-                    # Try parsing compact format first (8-10 digits)
+            # Priority 2: Try compact formats (10 digits, then 8 digits)
+            compact_patterns = self.dob_patterns[4:6]
+            for pattern in compact_patterns:
+                matches = re.findall(pattern, text)
+                if matches:
+                    date_str = matches[0].strip()
                     if date_str.isdigit() and 8 <= len(date_str) <= 10:
                         parsed_date = self._parse_compact_date(date_str)
                         if parsed_date:
+                            logger.debug(f"Found compact DOB: {parsed_date} from '{date_str}'")
                             return parsed_date
 
-                    # Try standard German date parsing
-                    parsed_date = self._parse_german_date(date_str)
-                    if parsed_date:
-                        return parsed_date
+            # Priority 3: Try dates with separators (last resort)
+            separator_pattern = self.dob_patterns[6]
+            matches = re.findall(separator_pattern, text)
+            if matches:
+                date_str = matches[0].strip()
+                parsed_date = self._parse_german_date(date_str)
+                if parsed_date:
+                    logger.debug(f"Found separator DOB: {parsed_date} from '{date_str}'")
+                    return parsed_date
 
             return None
 
